@@ -1,13 +1,13 @@
+#' @keywords internal 
+"_PACKAGE"
 #' Plotting Model Coefficients
-#'
-#' Provides an S3 generic method for plotting coefficients from a model so it can be extended to other model types.
-#'
-#' Currently, methods are available for lm, glm and rxLinMod objects.
-#'
-# @import plyr ggplot2 reshape2
-#' @docType package
+#' @description
+#' A short description...
+#'  Provides an S3 generic method for plotting coefficients from a model so it can be extended to other model types.
 #' @name coefplot
-#' @aliases coefplot-package
+# @aliases coefplot-package
+
+# @import plyr ggplot2 reshape2
 NULL
 
 
